@@ -59,7 +59,8 @@ def get_synchronization_tasks(object_name):
               'method': Object('check_current_binhost(update.cl_update_binhost)'),
               'condition': lambda GetBool, Get: (
                     not GetBool('update.cl_update_binhost_recheck_set') and
-                    not (Get('update.cl_update_binhost_choice') and Get('update.cl_update_binhost_choice') != 'auto') and
+                    not Get('update.cl_update_binhost_choice') and
+                    Get('update.cl_update_binhost_choice') != 'auto' and
                     Get('update.cl_update_sync_rep') and
                     Get('update.cl_update_binhost') and 
                     Get('update.cl_update_use_migration_host') == 'off')
